$%{headertitle}
Keywords: $%{keywords}

# $%{title}

## ($%{year})

$%{alt_title}

$%{tagline}

$%{plot}

#### $%{directornum}

$%{directors}

#### $%{writernum}

$%{writers}

#### $%{actornum}

$%{actors}

Runtime: $%{runtime} minutes

### Reviews:

#### Roger Ebert:

★★★★ ($%{rogername})

$%{rogertext1} (more)

$%{rogertextx}

#### IMDB User Rating:

$%{imdb_userrating}/10

#### Rotten Tomatoes:

$%{rotten_rating}

#### Metacritic:

$%{metacritic}